require 'faraday'
require 'json'

STATE_ENDPOINT = "http://repasse.ufabc.edu.br/transfgov/rest/estado"

module TransfGov
  class State
    attr_reader :id, :sigla, :regiao, :nome

    def initialize(attributes)
      @id = attributes["id"] 
      @sigla = attributes["sigla"]
      @regiao = attributes["regiao"]
      @nome = attributes["nome"]
    end

    def self.find(id)
      sigla = id.is_a?(Symbol) ? id.to_s.upcase : id.upcase
      response = Faraday.get("#{STATE_ENDPOINT}/#{sigla}")
      attributes = JSON.parse(response.body)
      new(attributes)
    end

    def self.all
      response = Faraday.get("#{STATE_ENDPOINT}")
      estados = JSON.parse(response.body)
      estados.map { |attributes| new(attributes) }
    end

    def cities
      response = Faraday.get("#{STATE_ENDPOINT}/#{sigla}/municipios")
      municipios = JSON.parse(response.body)
      municipios.map { |attributes| TransfGov::City.new(attributes) }
    end

  end
end